/*
 *	Title:		o3find
 *	Version:	0.8.2
 *	Created by:	Paolo Copello
 *	Home page:	http://web.tiscali.it/fanelia
 *	
 *	Copyright (C) 2003-2005 Paolo Copello
 *	
 *	******************************************
 *	This file is part of o3find
 *	******************************************
 *	
 *	o3find is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	any later version.
 *	
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *	
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *	
 */

#include "StdAfx.h"
#include "Options.h"
#include "o3find_wingui.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif



// REMEMBER tab

static const CString O3FIND_REMEMBER_FILE_TYPES		= _T("RememberFileTypes");
static const CString O3FIND_LAST_FILE_TYPE			= _T("LastFileType");

static const CString O3FIND_REMEMBER_SEARCH_TEXT	= _T("RememberSearchText");
static const CString O3FIND_LAST_SEARCH_TEXT		= _T("LastSearchText");

static const CString O3FIND_REMEMBER_DIRECTORY		= _T("RememberDirectory");
static const CString O3FIND_LAST_DIRECTORY			= _T("LastDirectory");

static const CString O3FIND_REMEMBER_MAIN_OPTIONS	= _T("RememberMainWindowOptions");

static const CString O3FIND_CASE_SENSITIVE			= _T("CaseSensitive");
static const CString O3FIND_SUB_FOLDERS				= _T("SubFolders");


// SETTINGS tab

static const CString O3FIND_REMEMBER_SETTINGS	= _T("RememberSettings");

static const CString O3FIND_CONTENT				= _T("Content");
static const CString O3FIND_META_DATA			= _T("MetaData");

static const CString O3FIND_ALREADY_OPEN		= _T("AlreadyOpen");
static const CString O3FIND_IGNORE_STYLE		= _T("IgnoreStyle");

// GENERAL...

static const CString O3FIND_VERSION				= _T("Version");


//static const CString O3FIND_O3_ONLY				= _T("O3Only");


CO3FindOptions::CO3FindOptions()
: 
	//REMEMBER
	m_bRememberFilesSearched(FALSE), 
	m_bRememberTextSearched(FALSE),
	m_bRememberDirectory(FALSE), 
	m_bRememberMainWindowOptions(FALSE), 
	m_bCaseSensitive(FALSE), 
	m_bSubFolders(FALSE), 
	// SETTINGS
	m_bRememberSettings(FALSE),
	m_bContent(TRUE),
	m_bMetaData(TRUE),
	m_bAlreadyOpen(TRUE),
	m_bIgnoreStyle(FALSE)
	// GENERAL
	//m_bChanged(FALSE)
{
}


int CO3FindOptions::LoadFromRegistry()
{
	// GENERAL...
	m_strVersion = GetApp()->GetProfileString(O3FIND_SETTINGS, 
										O3FIND_VERSION, O3FIND_DEFAULT_VERSION);
	

	// REMEMBER tab

	m_bRememberFilesSearched = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_REMEMBER_FILE_TYPES, FALSE);
	if (m_bRememberFilesSearched)
	{
		m_strLastFilesSearched = GetApp()->GetProfileString(O3FIND_SETTINGS, 
											O3FIND_LAST_FILE_TYPE, _T(""));
	}

	m_bRememberTextSearched = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_REMEMBER_SEARCH_TEXT, FALSE);
	if (m_bRememberTextSearched)
	{
		m_strLastTextSearched = GetApp()->GetProfileString(O3FIND_SETTINGS, 
											O3FIND_LAST_SEARCH_TEXT, _T(""));
	}

	m_bRememberDirectory = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_REMEMBER_DIRECTORY, FALSE);
	if (m_bRememberDirectory)
	{
		m_strLastDirectory = GetApp()->GetProfileString(O3FIND_SETTINGS, 
											O3FIND_LAST_DIRECTORY, _T(""));
	}

	m_bRememberMainWindowOptions = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_REMEMBER_MAIN_OPTIONS, FALSE);
	if (m_bRememberMainWindowOptions)
	{
		m_bCaseSensitive = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_CASE_SENSITIVE, TRUE);

		m_bSubFolders = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_SUB_FOLDERS, TRUE);
	}

	// SETTINGS tab

	m_bRememberSettings = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_REMEMBER_SETTINGS, FALSE);
	if (m_bRememberSettings)
	{
		m_bContent = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_CONTENT, TRUE);

		m_bMetaData = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_META_DATA, TRUE);

		m_bAlreadyOpen = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_ALREADY_OPEN, TRUE);

		m_bIgnoreStyle = GetApp()->GetProfileInt(O3FIND_SETTINGS, 
											O3FIND_IGNORE_STYLE, FALSE);
	}

	return 0;
}

int CO3FindOptions::SaveToRegistry()
{
	// GENERAL...
	GetApp()->WriteProfileString(O3FIND_SETTINGS, 
								O3FIND_VERSION, m_strVersion);

	// REMEMBER tab
	GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
							O3FIND_REMEMBER_FILE_TYPES, m_bRememberFilesSearched);
	
	if (m_bRememberFilesSearched)
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_FILE_TYPE, m_strLastFilesSearched);
	}
	else
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_FILE_TYPE, "");
	}

	GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
							O3FIND_REMEMBER_SEARCH_TEXT, m_bRememberTextSearched);

	if (m_bRememberTextSearched)
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_SEARCH_TEXT, m_strLastTextSearched);
	}
	else
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_SEARCH_TEXT, "");
	}

	GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
							O3FIND_REMEMBER_DIRECTORY, m_bRememberDirectory);

	if (m_bRememberDirectory)
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_DIRECTORY, m_strLastDirectory);
	}
	else
	{
		GetApp()->WriteProfileString(O3FIND_SETTINGS, 
									O3FIND_LAST_DIRECTORY, "");
	}

	GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
							O3FIND_REMEMBER_MAIN_OPTIONS, m_bRememberMainWindowOptions);

	if (m_bRememberMainWindowOptions)
	{
		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_CASE_SENSITIVE, m_bCaseSensitive);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_SUB_FOLDERS, m_bSubFolders);
	}
	else
	{
		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_CASE_SENSITIVE, TRUE);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_SUB_FOLDERS, TRUE);
	}

	// SETTINGS tab

	GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
							O3FIND_REMEMBER_SETTINGS, m_bRememberSettings);
	if (m_bRememberSettings)
	{
		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_CONTENT, m_bContent);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_META_DATA, m_bMetaData);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_ALREADY_OPEN, m_bAlreadyOpen);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_IGNORE_STYLE, m_bIgnoreStyle);
	}
	else
	{
		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_CONTENT, TRUE);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_META_DATA, TRUE);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_ALREADY_OPEN, TRUE);

		GetApp()->WriteProfileInt(O3FIND_SETTINGS, 
								O3FIND_IGNORE_STYLE, FALSE);
	}
	
	return 0;

}

int CO3FindOptions::DeleteFromRegistry()
{
	return 0;

}

int CO3FindOptions::DeleteFromRegistryAllUsers()
{
	return 0;

}

